VOOZH about

URL: https://doc.rust-lang.org/std/cmp/trait.PartialOrd.html

⇱ PartialOrd in std::cmp - Rust


Trait PartialOrd 

1.0.0 (const: unstable) · Source
pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>
where Rhs: ?Sized,
{ // Required method fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>; // Provided methods fn lt(&self, other: &Rhs) -> bool { ... } fn le(&self, other: &Rhs) -> bool { ... } fn gt(&self, other: &Rhs) -> bool { ... } fn ge(&self, other: &Rhs) -> bool { ... } }

Required Methods

Provided Methods

Implementors

Source

impl PartialOrd for AsciiChar

Source

impl PartialOrd for CharCase

1.34.0 (const: unstable) · Source

impl PartialOrd for Infallible

1.0.0 · Source

impl PartialOrd for ErrorKind

1.7.0 · Source

impl PartialOrd for IpAddr

Source

impl PartialOrd for Ipv6MulticastScope

1.0.0 · Source

impl PartialOrd for SocketAddr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ordering

1.0.0 (const: unstable) · Source

impl PartialOrd for bool

1.0.0 (const: unstable) · Source

impl PartialOrd for char

1.0.0 (const: unstable) · Source

impl PartialOrd for f16

1.0.0 (const: unstable) · Source

impl PartialOrd for f32

1.0.0 (const: unstable) · Source

impl PartialOrd for f64

1.0.0 (const: unstable) · Source

impl PartialOrd for f128

1.0.0 (const: unstable) · Source

impl PartialOrd for i8

1.0.0 (const: unstable) · Source

impl PartialOrd for i16

1.0.0 (const: unstable) · Source

impl PartialOrd for i32

1.0.0 (const: unstable) · Source

impl PartialOrd for i64

1.0.0 (const: unstable) · Source

impl PartialOrd for i128

1.0.0 (const: unstable) · Source

impl PartialOrd for isize

Source

impl PartialOrd for !

1.0.0 · Source

impl PartialOrd for str

Implements comparison operations on strings.

Strings are compared lexicographically by their byte values. This compares Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Comparing strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl PartialOrd for u8

1.0.0 (const: unstable) · Source

impl PartialOrd for u16

1.0.0 (const: unstable) · Source

impl PartialOrd for u32

1.0.0 (const: unstable) · Source

impl PartialOrd for u64

1.0.0 (const: unstable) · Source

impl PartialOrd for u128

1.0.0 (const: unstable) · Source

impl PartialOrd for ()

1.0.0 (const: unstable) · Source

impl PartialOrd for usize

1.27.0 · Source

impl PartialOrd for CpuidResult

1.0.0 · Source

impl PartialOrd for TypeId

Source

impl PartialOrd for ByteStr

Source

impl PartialOrd for ByteString

1.0.0 · Source

impl PartialOrd for CStr

1.64.0 · Source

impl PartialOrd for CString

1.0.0 · Source

impl PartialOrd for OsStr

1.0.0 · Source

impl PartialOrd for OsString

1.0.0 · Source

impl PartialOrd for Error

1.33.0 · Source

impl PartialOrd for PhantomPinned

Source

impl PartialOrd for Alignment

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv4Addr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv6Addr

1.0.0 · Source

impl PartialOrd for SocketAddrV4

1.0.0 · Source

impl PartialOrd for SocketAddrV6

1.10.0 · Source

impl PartialOrd for Location<'_>

1.0.0 · Source

impl PartialOrd for Path

1.0.0 · Source

impl PartialOrd for PathBuf

1.0.0 · Source

impl PartialOrd for String

1.3.0 · Source

impl PartialOrd for Duration

1.8.0 · Source

impl PartialOrd for Instant

1.8.0 · Source

impl PartialOrd for SystemTime

Source

impl PartialOrd<&ByteStr> for Cow<'_, str>

Source

impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialOrd<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialOrd<&ByteStr> for ByteString

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&OsStr> for OsString

1.8.0 · Source

impl PartialOrd<&OsStr> for Path

1.8.0 · Source

impl PartialOrd<&OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&Path> for OsStr

1.8.0 · Source

impl PartialOrd<&Path> for OsString

1.8.0 · Source

impl PartialOrd<&Path> for PathBuf

Source

impl PartialOrd<Cow<'_, str>> for &ByteStr

Source

impl PartialOrd<Cow<'_, str>> for ByteString

Source

impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialOrd<Cow<'_, ByteStr>> for ByteString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for PathBuf

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for PathBuf

Source

impl PartialOrd<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialOrd<Cow<'_, [u8]>> for ByteString

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv6Addr

1.0.0 · Source

impl PartialOrd<str> for OsStr

1.0.0 · Source

impl PartialOrd<str> for OsString

Source

impl PartialOrd<ByteStr> for ByteString

Source

impl PartialOrd<ByteString> for &ByteStr

Source

impl PartialOrd<ByteString> for Cow<'_, str>

Source

impl PartialOrd<ByteString> for Cow<'_, ByteStr>

Source

impl PartialOrd<ByteString> for Cow<'_, [u8]>

Source

impl PartialOrd<ByteString> for ByteStr

1.8.0 · Source

impl PartialOrd<OsStr> for &Path

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsStr> for OsString

1.8.0 · Source

impl PartialOrd<OsStr> for Path

1.8.0 · Source

impl PartialOrd<OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<OsString> for &OsStr

1.8.0 · Source

impl PartialOrd<OsString> for &Path

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsString> for OsStr

1.8.0 · Source

impl PartialOrd<OsString> for Path

1.8.0 · Source

impl PartialOrd<OsString> for PathBuf

1.16.0 · Source

impl PartialOrd<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialOrd<Ipv6Addr> for IpAddr

1.8.0 · Source

impl PartialOrd<Path> for &OsStr

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<Path> for OsStr

1.8.0 · Source

impl PartialOrd<Path> for OsString

1.8.0 · Source

impl PartialOrd<Path> for PathBuf

1.8.0 · Source

impl PartialOrd<PathBuf> for &OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for &Path

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<PathBuf> for OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for OsString

1.8.0 · Source

impl PartialOrd<PathBuf> for Path

1.0.0 · Source

impl<'a> PartialOrd for Component<'a>

1.0.0 · Source

impl<'a> PartialOrd for Prefix<'a>

Source

impl<'a> PartialOrd for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> PartialOrd for Components<'a>

1.0.0 · Source

impl<'a> PartialOrd for PrefixComponent<'a>

1.0.0 · Source

impl<'a, B> PartialOrd for Cow<'a, B>
where B: PartialOrd + ToOwned + ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&B> for &A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&mut B> for &mut A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

Source

impl<Dyn> PartialOrd for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> PartialOrd for F
where F: FnPtr,

1.0.0 · Source

impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
where K: PartialOrd, V: PartialOrd, A: Allocator + Clone,

1.41.0 · Source

impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialOrd<<Q as Deref>::Target>,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for Option<T>
where T: PartialOrd,

1.36.0 · Source

impl<T> PartialOrd for Poll<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> PartialOrd for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for [T]
where T: PartialOrd,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for (T₁, T₂, …, Tₙ)
where T: PartialOrd,

This trait is implemented for tuples up to twelve items long.

1.10.0 · Source

impl<T> PartialOrd for Cell<T>
where T: PartialOrd + Copy,

1.10.0 · Source

impl<T> PartialOrd for RefCell<T>
where T: PartialOrd + ?Sized,

Source

impl<T> PartialOrd for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialOrd for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> PartialOrd for ManuallyDrop<T>
where T: PartialOrd + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialOrd for NonZero<T>

1.74.0 · Source

impl<T> PartialOrd for Saturating<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for Wrapping<T>
where T: PartialOrd,

1.25.0 · Source

impl<T> PartialOrd for NonNull<T>
where T: ?Sized,

1.19.0 (const: unstable) · Source

impl<T> PartialOrd for Reverse<T>
where T: PartialOrd,

1.0.0 · Source

impl<T, A1, A2> PartialOrd<Vec<T, A2>> for Vec<T, A1>
where T: PartialOrd, A1: Allocator, A2: Allocator,

Implements comparison of vectors, lexicographically.

1.0.0 · Source

impl<T, A> PartialOrd for Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for BTreeSet<T, A>
where T: PartialOrd, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> PartialOrd for LinkedList<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for VecDeque<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Rc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueRc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Arc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueArc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 (const: unstable) · Source

impl<T, E> PartialOrd for Result<T, E>
where T: PartialOrd, E: PartialOrd,

Source

impl<T, U> PartialOrd<SyncView<U>> for SyncView<T>
where T: Sync + PartialOrd<U> + ?Sized, U: Sync + ?Sized,

1.0.0 (const: unstable) · Source

impl<T, const N: usize> PartialOrd for [T; N]
where T: PartialOrd,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> PartialOrd for Mask<T, N>

Source

impl<T, const N: usize> PartialOrd for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<Y, R> PartialOrd for CoroutineState<Y, R>
where Y: PartialOrd, R: PartialOrd,