pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>where
Rhs: ?Sized,{
// Required method
fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>;
// Provided methods
fn lt(&self, other: &Rhs) -> bool { ... }
fn le(&self, other: &Rhs) -> bool { ... }
fn gt(&self, other: &Rhs) -> bool { ... }
fn ge(&self, other: &Rhs) -> bool { ... }
}Required Methods
Provided Methods
Implementors
impl PartialOrd for AsciiChar
impl PartialOrd for CharCase
impl PartialOrd for Infallible
impl PartialOrd for ErrorKind
impl PartialOrd for IpAddr
impl PartialOrd for Ipv6MulticastScope
impl PartialOrd for SocketAddr
impl PartialOrd for Ordering
impl PartialOrd for bool
impl PartialOrd for char
impl PartialOrd for f16
impl PartialOrd for f32
impl PartialOrd for f64
impl PartialOrd for f128
impl PartialOrd for i8
impl PartialOrd for i16
impl PartialOrd for i32
impl PartialOrd for i64
impl PartialOrd for i128
impl PartialOrd for isize
impl PartialOrd for !
impl PartialOrd for str
Implements comparison operations on strings.
Strings are compared lexicographically by their byte values. This compares Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Comparing strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl PartialOrd for u8
impl PartialOrd for u16
impl PartialOrd for u32
impl PartialOrd for u64
impl PartialOrd for u128
impl PartialOrd for ()
impl PartialOrd for usize
impl PartialOrd for CpuidResult
impl PartialOrd for TypeId
impl PartialOrd for ByteStr
impl PartialOrd for ByteString
impl PartialOrd for CStr
impl PartialOrd for CString
impl PartialOrd for OsStr
impl PartialOrd for OsString
impl PartialOrd for Error
impl PartialOrd for PhantomPinned
impl PartialOrd for Alignment
impl PartialOrd for Ipv4Addr
impl PartialOrd for Ipv6Addr
impl PartialOrd for SocketAddrV4
impl PartialOrd for SocketAddrV6
impl PartialOrd for Location<'_>
impl PartialOrd for Path
impl PartialOrd for PathBuf
impl PartialOrd for String
impl PartialOrd for Duration
impl PartialOrd for Instant
impl PartialOrd for SystemTime
impl PartialOrd<&ByteStr> for Cow<'_, str>
impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
impl PartialOrd<&ByteStr> for Cow<'_, [u8]>
impl PartialOrd<&ByteStr> for ByteString
impl PartialOrd<&OsStr> for Cow<'_, OsStr>
impl PartialOrd<&OsStr> for Cow<'_, Path>
impl PartialOrd<&OsStr> for OsString
impl PartialOrd<&OsStr> for Path
impl PartialOrd<&OsStr> for PathBuf
impl PartialOrd<&Path> for Cow<'_, OsStr>
impl PartialOrd<&Path> for Cow<'_, Path>
impl PartialOrd<&Path> for OsStr
impl PartialOrd<&Path> for OsString
impl PartialOrd<&Path> for PathBuf
impl PartialOrd<Cow<'_, str>> for &ByteStr
impl PartialOrd<Cow<'_, str>> for ByteString
impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr
impl PartialOrd<Cow<'_, ByteStr>> for ByteString
impl PartialOrd<Cow<'_, OsStr>> for &OsStr
impl PartialOrd<Cow<'_, OsStr>> for &Path
impl PartialOrd<Cow<'_, OsStr>> for OsStr
impl PartialOrd<Cow<'_, OsStr>> for OsString
impl PartialOrd<Cow<'_, OsStr>> for Path
impl PartialOrd<Cow<'_, OsStr>> for PathBuf
impl PartialOrd<Cow<'_, Path>> for &OsStr
impl PartialOrd<Cow<'_, Path>> for &Path
impl PartialOrd<Cow<'_, Path>> for OsStr
impl PartialOrd<Cow<'_, Path>> for OsString
impl PartialOrd<Cow<'_, Path>> for Path
impl PartialOrd<Cow<'_, Path>> for PathBuf
impl PartialOrd<Cow<'_, [u8]>> for &ByteStr
impl PartialOrd<Cow<'_, [u8]>> for ByteString
impl PartialOrd<IpAddr> for Ipv4Addr
impl PartialOrd<IpAddr> for Ipv6Addr
impl PartialOrd<str> for OsStr
impl PartialOrd<str> for OsString
impl PartialOrd<ByteStr> for ByteString
impl PartialOrd<ByteString> for &ByteStr
impl PartialOrd<ByteString> for Cow<'_, str>
impl PartialOrd<ByteString> for Cow<'_, ByteStr>
impl PartialOrd<ByteString> for Cow<'_, [u8]>
impl PartialOrd<ByteString> for ByteStr
impl PartialOrd<OsStr> for &Path
impl PartialOrd<OsStr> for Cow<'_, OsStr>
impl PartialOrd<OsStr> for Cow<'_, Path>
impl PartialOrd<OsStr> for OsString
impl PartialOrd<OsStr> for Path
impl PartialOrd<OsStr> for PathBuf
impl PartialOrd<OsString> for &OsStr
impl PartialOrd<OsString> for &Path
impl PartialOrd<OsString> for Cow<'_, OsStr>
impl PartialOrd<OsString> for Cow<'_, Path>
impl PartialOrd<OsString> for OsStr
impl PartialOrd<OsString> for Path
impl PartialOrd<OsString> for PathBuf
impl PartialOrd<Ipv4Addr> for IpAddr
impl PartialOrd<Ipv6Addr> for IpAddr
impl PartialOrd<Path> for &OsStr
impl PartialOrd<Path> for Cow<'_, OsStr>
impl PartialOrd<Path> for Cow<'_, Path>
impl PartialOrd<Path> for OsStr
impl PartialOrd<Path> for OsString
impl PartialOrd<Path> for PathBuf
impl PartialOrd<PathBuf> for &OsStr
impl PartialOrd<PathBuf> for &Path
impl PartialOrd<PathBuf> for Cow<'_, OsStr>
impl PartialOrd<PathBuf> for Cow<'_, Path>
impl PartialOrd<PathBuf> for OsStr
impl PartialOrd<PathBuf> for OsString
impl PartialOrd<PathBuf> for Path
impl<'a> PartialOrd for Component<'a>
impl<'a> PartialOrd for Prefix<'a>
impl<'a> PartialOrd for PhantomContravariantLifetime<'a>
impl<'a> PartialOrd for PhantomCovariantLifetime<'a>
impl<'a> PartialOrd for PhantomInvariantLifetime<'a>
impl<'a> PartialOrd for Components<'a>
impl<'a> PartialOrd for PrefixComponent<'a>
impl<'a, B> PartialOrd for Cow<'a, B>
impl<A, B> PartialOrd<&B> for &A
impl<A, B> PartialOrd<&mut B> for &mut A
impl<Dyn> PartialOrd for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> PartialOrd for Fwhere
F: FnPtr,
impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
impl<T> PartialOrd for Option<T>where
T: PartialOrd,
impl<T> PartialOrd for Poll<T>where
T: PartialOrd,
impl<T> PartialOrd for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> PartialOrd for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> PartialOrd for [T]where
T: PartialOrd,
Implements comparison of slices lexicographically.
impl<T> PartialOrd for (T₁, T₂, …, Tₙ)where
T: PartialOrd,
This trait is implemented for tuples up to twelve items long.
impl<T> PartialOrd for Cell<T>where
T: PartialOrd + Copy,
impl<T> PartialOrd for RefCell<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for PhantomContravariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomCovariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomData<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomInvariant<T>where
T: ?Sized,
impl<T> PartialOrd for ManuallyDrop<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for NonZero<T>where
T: ZeroablePrimitive + PartialOrd,
impl<T> PartialOrd for Saturating<T>where
T: PartialOrd,
impl<T> PartialOrd for Wrapping<T>where
T: PartialOrd,
impl<T> PartialOrd for NonNull<T>where
T: ?Sized,
impl<T> PartialOrd for Reverse<T>where
T: PartialOrd,
impl<T, A1, A2> PartialOrd<Vec<T, A2>> for Vec<T, A1>
Implements comparison of vectors, lexicographically.
impl<T, A> PartialOrd for Box<T, A>
impl<T, A> PartialOrd for BTreeSet<T, A>
impl<T, A> PartialOrd for LinkedList<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for VecDeque<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for Rc<T, A>
impl<T, A> PartialOrd for UniqueRc<T, A>
impl<T, A> PartialOrd for Arc<T, A>
impl<T, A> PartialOrd for UniqueArc<T, A>
impl<T, E> PartialOrd for Result<T, E>where
T: PartialOrd,
E: PartialOrd,
impl<T, U> PartialOrd<SyncView<U>> for SyncView<T>
impl<T, const N: usize> PartialOrd for [T; N]where
T: PartialOrd,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> PartialOrd for Mask<T, N>where
T: MaskElement + PartialOrd,
impl<T, const N: usize> PartialOrd for Simd<T, N>where
T: SimdElement + PartialOrd,
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.